@@ -1,8 +1,22 @@
 # convert a set of horizon depths and property into a continuous sequence
 # returning a vector of standardized length
 # suitable for slotting
+# horizons must be in order by depth!
 unroll <- function(top, bottom, prop, max_depth, bottom_padding_value=NA)
 	{
+	# are horizons in the correct order?
+	if(! all.equal(top,sort(top)))
+		stop('Error: horizons are not sorted by depth.')
+	
+	# number of horizons
+	n.horizons <- length(top)
+	
+	# all bottom values above the last horizon should be in the SET of top values below the first horizon
+	hz.test.bottom_hz_in_top <- bottom[-n.horizons] %in% top[-1]
+	if(length(which(hz.test.bottom_hz_in_top)) != (n.horizons - 1))
+		{
+		stop('Error: bad horizon structure')
+		}
 	
 	# inverse RLE, to generate repeating sequence of property, n times
 	p <- inverse.rle(list(lengths=bottom-top, values=prop))
